/**
 * Copyright 2011 Niall Gallagher
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.googlecode.mobilityrpc.protocol.converters.messages;

import com.google.protobuf.ByteString;
import com.googlecode.mobilityrpc.protocol.converters.MessageConverter;
import com.googlecode.mobilityrpc.protocol.converters.components.RequestIdentifierComponentConverter;
import com.googlecode.mobilityrpc.protocol.pojo.ExecutionMode;
import com.googlecode.mobilityrpc.protocol.pojo.ExecutionRequest;
import com.googlecode.mobilityrpc.protocol.pojo.SerializationFormat;
import com.googlecode.mobilityrpc.protocol.protobuf.ComponentSerializationFormat;
import com.googlecode.mobilityrpc.protocol.protobuf.MessageExecutionRequest;

/**
 * @author Niall Gallagher
 */
public class ExecutionRequestMessageConverter extends MessageConverter<ExecutionRequest> {

    private final RequestIdentifierComponentConverter requestIdentifierConverter = new RequestIdentifierComponentConverter();

    @Override
    protected ExecutionRequest fromProtobuf(byte[] bytes) throws Exception {
        com.googlecode.mobilityrpc.protocol.protobuf.MessageExecutionRequest.ExecutionRequest.Builder builder = com.googlecode.mobilityrpc.protocol.protobuf.MessageExecutionRequest.ExecutionRequest.newBuilder();
        builder.mergeFrom(bytes);
        return new ExecutionRequest(
                builder.getSerializedExecutableObject().toByteArray(),
                SerializationFormat.valueOf(builder.getSerializationFormat().name()),
                ExecutionMode.valueOf(builder.getExecutionMode().name()),
                requestIdentifierConverter.convertFromProtobuf(builder.getRequestIdentifier())
        );
    }

    @Override
    protected byte[] toProtobuf(ExecutionRequest object) throws Exception {
        com.googlecode.mobilityrpc.protocol.protobuf.MessageExecutionRequest.ExecutionRequest.Builder builder = com.googlecode.mobilityrpc.protocol.protobuf.MessageExecutionRequest.ExecutionRequest.newBuilder();
        builder.setSerializedExecutableObject(ByteString.copyFrom(object.getSerializedExecutableObject()));
        builder.setSerializationFormat(ComponentSerializationFormat.SerializationFormat.valueOf(object.getSerializationFormat().name()));
        builder.setExecutionMode(MessageExecutionRequest.ExecutionRequest.ExecutionMode.valueOf(object.getExecutionMode().name()));

        builder.setRequestIdentifier(
                requestIdentifierConverter.convertToProtobuf(object.getRequestIdentifier())
        );

        return builder.build().toByteArray();
    }
}
